@@ -17,7 +17,7 @@ Check results from Pathway Tools command:
 -check_mpwt_pathologic_runs: results from PathoLogic (by looking at pathologic.log)
 -check_dat: attribute-values dat files
 """
-
+import chardet
 import csv
 import os
 import logging
@@ -72,9 +72,10 @@ def extract_pathologic(patho_log):
         log_resume_list.append([organism_name, 'ERROR', '', '', '', ''])
         logger.info('No pathologic log for {0}, an error occured before PathoLogic run.'.format(organism_name))
         return
-
-    with open(patho_log, 'r') as input_file:
-        for index, line in enumerate(input_file):
+    with open(patho_log, 'rb') as log_file:
+        for index, line in enumerate(iter(log_file.readline, b'')):
+            encoding = chardet.detect(line)['encoding']
+            line = line.decode(encoding, errors='replace')
             if ';;; Error:' in line:
                 non_fatal_error_count += 1
             if 'Warning:' in line:
@@ -83,6 +84,10 @@ def extract_pathologic(patho_log):
                 fatal_error_index = index
                 log_str += line
                 log_resume_list.append([organism_name, 'ERROR', '', '', '', ''])
+            if 'Pathologic build aborted.' in line:
+                fatal_error_index = index
+                log_str += line
+                log_resume_list.append([organism_name, 'ERROR', '', '', '', ''])
 
             if fatal_error_index:
                 if index > fatal_error_index:
@@ -166,7 +171,7 @@ def check_mpwt_pathologic_runs(species_input_folder_paths, patho_log_folder):
             elif species_pathologic_informations[3] is None and species_pathologic_informations[4] is not None:
                 failed_inferences.append(species_pathologic_informations[0])
         else:
-            logger.info('|Output Check|WARNING: No pathologic.log file for {0}, could not write log.'.format(species_input_folder_path))
+            logger.info('|Output Check| WARNING: No pathologic.log file for {0}, could not write log.'.format(species_input_folder_path))
             base_name = os.path.basename(species_input_folder_path)
             no_pathologic_files.append(base_name)
             log_str = ''
@@ -187,7 +192,7 @@ def check_mpwt_pathologic_runs(species_input_folder_paths, patho_log_folder):
     if number_passed_inference > 0:
         logger.info('|Output Check| {0} on {1} {2} passed!'.format(str(number_passed_inference), str(number_total_build), string_passed_build))
     if number_failed_inference > 0:
-        logger.critical('|Output Check|WARNING: {0} on {1} {2} failed: {3}! See the log for more information.'.format(str(number_failed_inference), str(number_total_build), string_failed_build, ' '.join(failed_inferences)))
+        logger.critical('|Output Check| WARNING: {0} on {1} {2} failed: {3}! See the log for more information.'.format(str(number_failed_inference), str(number_total_build), string_failed_build, ' '.join(failed_inferences)))
 
     if patho_log_folder:
         patho_error_pathname = os.path.join(patho_log_folder, 'log_error.txt')
